%% Filename: PAM_Lec02_B0_Free_Precession.m
% Demonstrate the precession of the bulk magnetization vector.

%% Define some constants
gamma=42.57e6;         % Gyromagnetic ratio for 1H [MHz/T]
B0=1.5;                % B0 magnetic field strength [T]
dt=0.01e-8;            % Time step [s]
nt=500;                % Number of time points to simulate
t=(0:nt-1)*0.01e-8;    % Time vector [s]

M0=[sqrt(2)/2 0 sqrt(2)/2 1]';  % Initial condition (I.C.)

M=zeros(4,nt);                  % Initialize the magnetization array
M(:,1)=M0;                      % Define the first time point as the I.C.

%% Simulate precession of the bulk magnetization vector
dB0=PAM_B0_op(gamma,B0,dt);     % Calculate the homogenous coordinate transform

for n=2:nt
  M(:,n)=dB0*M(:,n-1);
end

%% Plot the results
figure; hold on;
  p(1)=plot(t,M(1,:));          % Plot the Mx component
  p(2)=plot(t,M(2,:));          % Plot the My component
  p(3)=plot(t,M(3,:));          % Plot the Mz component
    set(p,'LineWidth',3);       % Increase plot thickness
  ylabel('Magnetization [AU]');
  xlabel('Time [s]');
  legend('M_x','M_y','M_z');
  title('Bulk Magnetization Components as f(t)');
  
